@@ -25,6 +25,7 @@
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 #include "ut_vector.h"
+#include "ut_Win32OS.h"
 #include "ev_Win32Toolbar.h"
 #include "xap_Win32App.h"
 #include "xap_Frame.h"
@@ -35,6 +36,7 @@
 #include "ev_Toolbar_Control.h"
 #include "ev_EditEventMapper.h"
 #include "xap_Win32Toolbar_Icons.h"
+#include "xap_EncodingManager.h"
 #include "ev_Win32Toolbar_ViewListener.h"
 #include "xav_View.h"
 #include "ut_xml.h"
@@ -109,6 +111,7 @@ foo_Bitmap_container::~foo_Bitmap_container()
 	}
 }
 
+
 /*****************************************************************/
 
 
@@ -242,12 +245,22 @@ bool EV_Win32Toolbar::toolbarEvent(XAP_Toolbar_Id id,
 #endif
 
 WHICHPROC s_lpfnDefCombo; 
-WHICHPROC s_lpfnDefComboEdit; 
+WHICHPROC s_lpfnDefToolBar;
 
 
 #define COMBO_BUF_LEN 256
 
 
+
+LRESULT CALLBACK EV_Win32Toolbar::_ToolBarWndProc (HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM lParam)
+{
+	if (uMessage == WM_CTLCOLORSTATIC) {
+		return (LRESULT) GetSysColorBrush (COLOR_WINDOW);
+	}
+	
+	return (CallWindowProc(s_lpfnDefToolBar, hWnd, uMessage, wParam, lParam));
+}
+
 LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM lParam)
 {
 	switch (uMessage)
@@ -514,29 +527,32 @@ bool EV_Win32Toolbar::synthesize(void)
 
 	// NOTE: this toolbar will get placed later, by frame or rebar
 
-	m_hwnd = CreateWindowEx(0, 
-				TOOLBARCLASSNAME,		// window class name
-				(LPSTR) NULL,			// window caption
-				WS_CHILD | WS_VISIBLE 
-				| WS_CLIPCHILDREN | WS_CLIPSIBLINGS 
-				| TBSTYLE_TOOLTIPS | TBSTYLE_FLAT
-				| ( bText && !bIcons ? TBSTYLE_LIST : 0 )
-				| TBSTYLE_CUSTOMERASE
-				| CCS_NOPARENTALIGN | CCS_NODIVIDER
-				| CCS_NORESIZE
-				,						// window style
-				0,						// initial x position
-				0,						// initial y position
-				0,						// initial x size
-				0,						// initial y size
-				hwndParent,				// parent window handle
-				NULL,					// window menu handle
-				m_pWin32App->getInstance(),		// program instance handle
-				NULL);					// creation parameters
+	m_hwnd = UT_CreateWindowEx(0, 
+							   TOOLBARCLASSNAME, // window class name
+							   (LPSTR) NULL,			// window caption
+							   WS_CHILD | WS_VISIBLE 
+							   | WS_CLIPCHILDREN | WS_CLIPSIBLINGS 
+							   | TBSTYLE_TOOLTIPS | TBSTYLE_FLAT
+							   | ( bText && !bIcons ? TBSTYLE_LIST : 0 )
+							   | TBSTYLE_CUSTOMERASE
+							   | CCS_NOPARENTALIGN | CCS_NODIVIDER
+							   | CCS_NORESIZE
+							   ,						// window style
+							   0,						// initial x position
+							   0,						// initial y position
+							   0,						// initial x size
+							   0,						// initial y size
+							   hwndParent,				// parent window handle
+							   NULL,					// window menu handle
+							   m_pWin32App->getInstance(),		// program instance handle
+							   NULL);  // creation parameters
+							   					
 
 	UT_ASSERT(m_hwnd);
 
-	// override the window procedure 	
+	// override the window procedure 		
+	s_lpfnDefToolBar = (WHICHPROC)GetWindowLong(m_hwnd, GWL_WNDPROC);
+	SetWindowLong(m_hwnd, GWL_WNDPROC, (LONG)_ToolBarWndProc);
 	SetWindowLong(m_hwnd, GWL_USERDATA, (LONG)this);
 
 
@@ -643,7 +659,7 @@ bool EV_Win32Toolbar::synthesize(void)
 
 						// create a matching child control
 						DWORD dwStyle = WS_CHILD | WS_BORDER | WS_VISIBLE | WS_VSCROLL |
-								CBS_HASSTRINGS | CBS_DROPDOWNLIST;
+								CBS_HASSTRINGS | CBS_DROPDOWN;
 
 						if ((pControl) && (pControl->shouldSort()))
 						{
@@ -653,7 +669,7 @@ bool EV_Win32Toolbar::synthesize(void)
 						if (id==AP_TOOLBAR_ID_FMT_FONT)
 							dwStyle |= CBS_OWNERDRAWFIXED;
 
-						HWND hwndCombo = CreateWindowEx ( 0L,   // No extended styles.
+						HWND hwndCombo = UT_CreateWindowEx ( 0L,   // No extended styles.
 							"COMBOBOX",						// Class name.
 							"",								// Default text.
 							dwStyle,						// Styles and defaults.
@@ -665,6 +681,15 @@ bool EV_Win32Toolbar::synthesize(void)
 
 						UT_ASSERT(hwndCombo);
 						
+						/*
+						 * Hack to create a combobox that is readonly, but which is capable of displaying text in 
+						 * the edit control which differs from that in the drop-down list like GTK combos.
+						 */
+						HWND hwndEdit = FindWindowEx(hwndCombo, 0, NULL, NULL);
+						if (!hwndEdit)
+							UT_DEBUGMSG(("Toolbar: Failed to get handle of combos edit controls. Not setting read-only.\n"));
+						else
+							SendMessage(hwndEdit, EM_SETREADONLY, (WPARAM)TRUE, (LPARAM)0);
 						SendMessage(hwndCombo, WM_SETFONT, (WPARAM)GetStockObject(DEFAULT_GUI_FONT), MAKELPARAM(TRUE, 0));
 						SendMessage(hwndCombo, CB_SETDROPPEDWIDTH,(WPARAM)pControl->getDroppedWidth(), 0);
 
@@ -709,9 +734,9 @@ bool EV_Win32Toolbar::synthesize(void)
 								szToolTip = pLabel->getStatusMsg();
 							}
 
+
 							// Fill in the TOOLINFO structure.
 							TOOLINFO ti;
-
 							ti.cbSize = sizeof(ti);
 							ti.uFlags = TTF_IDISHWND | TTF_CENTERTIP;
 							ti.lpszText = (char *) szToolTip;
@@ -787,7 +812,8 @@ bool EV_Win32Toolbar::synthesize(void)
 					if (bText)
 					{
 						const char * szLabel = pLabel->getToolbarLabel();
-						// As long as translators don't cut the text short, we need to autosize just to squize anything insize 1280 :)
+						// As long as translators don't cut the text short,
+						// we need to autosize just to squize anything insize 1280 :)
 						tbb.fsStyle |= TBSTYLE_AUTOSIZE;
 						tbb.iString = SendMessage(m_hwnd, TB_ADDSTRING, (WPARAM) 0, (LPARAM) (LPSTR) szLabel);
 					}
@@ -1049,6 +1075,7 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 					break;
 				}					
 				
+				szState = XAP_EncodingManager::get_instance()->strToNative(szState, "UTF-8");
 				
 				// Find the proper non-localised text
 				const char* pLocalised = szState;
@@ -1062,12 +1089,41 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 					
 												
 				int idx = SendMessage(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)pLocalised);
+				/*
+				 * If the string didn't exist within the combos list, we handle things differently for
+				 * different combos.
+				 */
 				if (idx==CB_ERR)
 				{
-                    // String not found, if the combo box has an "Other..." string, select it
-					const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
-					pSS->getValue(XAP_STRING_ID_TB_Zoom_Percent);
-					idx = SendMessage(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)pSS->getValue(XAP_STRING_ID_TB_Zoom_Percent));
+					const XAP_StringSet * pSS;
+					
+					switch (id)
+					{
+					/*
+					 * In the case of the font and font size combo, this means that the document contains a font not
+					 * installed on the system. Add it to the edit control, as is the case with the unix version.
+					 */
+					case AP_TOOLBAR_ID_FMT_SIZE:
+					case AP_TOOLBAR_ID_FMT_FONT:
+						idx = SendMessage(hwndCombo, WM_SETTEXT, (WPARAM)-1, (LPARAM)pLocalised);
+						if (idx == CB_ERR)
+							UT_DEBUGMSG(("refreshToolbar: Failed to set text for font combo.\n"));
+						break;
+					/* 
+					 * If this is the zoom combo, select the "Other..." string.
+					 */
+					case AP_TOOLBAR_ID_ZOOM:
+						pSS = XAP_App::getApp()->getStringSet();
+						idx = SendMessage(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)pSS->getValue(XAP_STRING_ID_TB_Zoom_Percent));
+						break;
+
+					case AP_TOOLBAR_ID_FMT_STYLE:
+						UT_DEBUGMSG(("refreshToolbar: Unknown string selected in style combo.\n"));
+						break;
+					default:
+						UT_DEBUGMSG(("refreshToolbar: Unknown string selected in unknown combo.\n"));
+						break;
+					}
 				}
 	
 				//UT_DEBUGMSG(("refreshToolbar: ComboBox [%s] is %s and %s\n",
