@@ -277,7 +277,6 @@ GOFFSET *       GR_Win32USPRenderInfo::s_pGoffsets          = NULL;
 
 GR_Win32USPGraphics::GR_Win32USPGraphics(HDC hdc, HWND hwnd, XAP_App * pApp)
 	:GR_Win32Graphics(hdc, hwnd, pApp),
-	 m_iDCFontAllocNo(0),
 	 m_bConstructorSucceeded(false)
 {
 	if(!_constructorCommonCode())
@@ -293,7 +292,6 @@ GR_Win32USPGraphics::GR_Win32USPGraphics(HDC hdc, HWND hwnd, XAP_App * pApp)
 GR_Win32USPGraphics::GR_Win32USPGraphics(HDC hdc, const DOCINFO * pDI, XAP_App * pApp,
 										 HGLOBAL hDevMode)
 	:GR_Win32Graphics(hdc, pDI, pApp, hDevMode),
-	 m_iDCFontAllocNo(0),
 	 m_bConstructorSucceeded(false)
 {
 	if(!_constructorCommonCode())
@@ -530,7 +528,7 @@ UT_uint32 GR_Win32USPGraphics::getFontHeight()
 		_setupFontOnDC((GR_Win32USPFont*)m_pFont, false);
 	}
 	
-	return (UT_uint32)((m_pFont->getHeight(m_hdc, getPrintDC())) * getResolution() / getDeviceResolution());
+	return (UT_uint32)(m_pFont->getHeight(m_hdc, getPrintDC()));
 }
 
 UT_uint32 GR_Win32USPGraphics::getFontAscent(GR_Font* fnt)
@@ -554,7 +552,7 @@ UT_uint32 GR_Win32USPGraphics::getFontAscent()
 		_setupFontOnDC((GR_Win32USPFont*)m_pFont, false);
 	}
 	
-	return (UT_uint32)((m_pFont->getAscent(m_hdc, getPrintDC())) * getResolution() / getDeviceResolution());
+	return (UT_uint32)(m_pFont->getAscent(m_hdc, getPrintDC()));
 }
 
 UT_uint32 GR_Win32USPGraphics::getFontDescent(GR_Font* fnt)
@@ -578,7 +576,7 @@ UT_uint32 GR_Win32USPGraphics::getFontDescent()
 		_setupFontOnDC((GR_Win32USPFont*)m_pFont, false);
 	}
 	
-	return (UT_uint32)((m_pFont->getDescent(m_hdc, getPrintDC())) * getResolution() / getDeviceResolution());
+	return (UT_uint32)(m_pFont->getDescent(m_hdc, getPrintDC()));
 }
 
 /*!
@@ -624,7 +622,7 @@ void GR_Win32USPGraphics::_setupFontOnDC(GR_Win32USPFont *pFont, bool bZoomMe)
 		// achieve true WYSIWIG), the letters, particularly, the descending parts, can be
 		// drawn outwith the line rectangle (and so leave pixel dirt, etc.)
 		// In order to avoid that, we actually request a slightly smaller font from the
-		// system if the physical pixel size drops below certain (heristically determined) value.
+		// system if the physical pixel size drops below certain (heuristically determined) value.
 		zoom = getZoomPercentage();
 		double dZoom = (double)zoom;
 		double dSizeFactor = dZoom * (double)pFont->getUnscaledHeight()/(double)getDeviceResolution();
@@ -642,8 +640,7 @@ void GR_Win32USPGraphics::_setupFontOnDC(GR_Win32USPFont *pFont, bool bZoomMe)
 	{
 		// we are using the printer dc for measuring, so we do not do any scaling
 		zoom = 100;
-		UT_uint32 iHeight = (UT_uint32)pFont->getPointSize();
-		pixels = MulDiv(iHeight, m_nPrintLogPixelsY, 72);
+		pixels = (int)(pFont->getPointSize() * (double)m_nPrintLogPixelsY / 72.0 + 0.5);
 		hdc = getPrintDC();
 	}
 	else
@@ -662,8 +659,14 @@ void GR_Win32USPGraphics::_setupFontOnDC(GR_Win32USPFont *pFont, bool bZoomMe)
 		hFont = pFont->getFontFromCache(pixels, false, zoom);
 	}
 
-	if(pFont->getAllocNumber() != m_iDCFontAllocNo ||
-	   (HFONT) GetCurrentObject(hdc, OBJ_FONT) != hFont)
+	bool bAllocNoMismatch = false;
+	if(hdc == m_hdc && pFont->getAllocNumber() != m_iDCFontAllocNo)
+		bAllocNoMismatch = true;
+
+	if(!bAllocNoMismatch && hdc == getPrintDC() && pFont->getAllocNumber() != m_iPrintDCFontAllocNo)
+		bAllocNoMismatch = true;
+	
+	if(bAllocNoMismatch || (HFONT) GetCurrentObject(hdc, OBJ_FONT) != hFont)
 	{
 		if(NULL == SelectObject(hdc, hFont))
 		{
@@ -693,8 +696,15 @@ void GR_Win32USPGraphics::_setupFontOnDC(GR_Win32USPFont *pFont, bool bZoomMe)
 
 			LocalFree( lpMsgBuf );
 		}
-		
-		m_iDCFontAllocNo = pFont->getAllocNumber();
+
+		// remember which font we loaded
+		// NB: when printing both of these are true (m_hdc == printDC)
+		if(hdc == m_hdc)
+			m_iDCFontAllocNo = pFont->getAllocNumber();
+
+		if(hdc == getPrintDC())
+			m_iPrintDCFontAllocNo = pFont->getAllocNumber();
+			
 	}
 }
 
@@ -836,6 +846,9 @@ bool GR_Win32USPGraphics::shape(GR_ShapingInfo & si, GR_RenderInfo *& ri)
 		RI->m_iClustSize = si.m_iLength;
 	}
 
+	// remove any justification information -- it will have to be recalculated
+	delete[] RI->m_pJustify; RI->m_pJustify = NULL;
+	
 	// to save time we will use a reasonably sized static buffer and
 	// will only allocate one on heap if the static one is too small.
 	static WCHAR wcInChars[GRWIN32USP_CHARBUFF_SIZE]; 
@@ -1073,6 +1086,11 @@ bool GR_Win32USPGraphics::shape(GR_ShapingInfo & si, GR_RenderInfo *& ri)
 		// no, this is necessary
 		RI->s_pOwnerChar = NULL;
 	}
+
+	if(RI->s_pOwnerDraw == RI)
+	{
+		RI->s_pOwnerDraw = NULL;
+	}
 	
 	return true;
 }
@@ -1300,7 +1318,7 @@ void GR_Win32USPGraphics::renderChars(GR_RenderInfo & ri)
 			pFont->setScreenAscent(iAscentScreen);
 		}
 
-		UT_sint32 iAscentPrint = pFont->getTextMetric().tmAscent * getResolution() / getDeviceResolution();
+		UT_sint32 iAscentPrint = pFont->getTextMetric().tmAscent;
 		yoff = _tduY(RI.m_yoff + iAscentPrint - iAscentScreen);
 	}
 	
@@ -1320,6 +1338,8 @@ void GR_Win32USPGraphics::renderChars(GR_RenderInfo & ri)
 	if(RI.m_bShapingFailed)
 		pItem->m_si.a.eScript = GRScriptType_Undefined;
 
+	SetTextAlign(m_hdc, TA_LEFT | TA_TOP);
+	
 	HRESULT hRes = fScriptTextOut(m_hdc, pFont->getScriptCache(), xoff, yoff,
 								  dFlags, /*option flags*/
 								  NULL, /*not sure about this*/
@@ -1387,7 +1407,7 @@ void GR_Win32USPGraphics::setPrintDC(HDC dc)
 					GR_Graphics * pG = pView->getGraphics();
 
 					if(pG == this)
-						pView->rebuildLayout();
+						pView->fontMetricsChange();
 				}
 			}
 		}
@@ -1432,7 +1452,7 @@ void GR_Win32USPGraphics::measureRenderedCharWidths(GR_RenderInfo & ri)
 
 		if(getPrintDC())
 		{
-			// we also need to remeasure the font metrics as well
+			// we also need to remeasure the font metrics
 			// and scale it down for the screen
 			_setupFontOnDC(pFont, false);
 			bFontSetUpOnDC = true;
@@ -1446,9 +1466,9 @@ void GR_Win32USPGraphics::measureRenderedCharWidths(GR_RenderInfo & ri)
 			GetTextMetrics(printHDC, &tm2);
 			DeleteDC(printHDC);
 #endif
-			pFont->setHeight(MulDiv(tm.tmHeight, getDeviceResolution(), m_nPrintLogPixelsY));
-			pFont->setAscent(MulDiv(tm.tmAscent, getDeviceResolution(), m_nPrintLogPixelsY));
-			pFont->setDescent(MulDiv(tm.tmDescent, getDeviceResolution(), m_nPrintLogPixelsY));
+			pFont->setHeight(MulDiv(tm.tmHeight, getResolution(), m_nPrintLogPixelsY));
+			pFont->setAscent(MulDiv(tm.tmAscent, getResolution(), m_nPrintLogPixelsY));
+			pFont->setDescent(MulDiv(tm.tmDescent, getResolution(), m_nPrintLogPixelsY));
 		}
 	}
 
@@ -1713,6 +1733,9 @@ bool GR_Win32USPGraphics::_scriptBreak(GR_Win32USPRenderInfo &ri)
 			ri.s_pChars[i] = (WCHAR)ri.m_pText->getChar();
 		}
 
+		// restore the iterrator to the initial position
+		*(ri.m_pText) -= iLen;
+		
 		GR_Win32USPItem &I = (GR_Win32USPItem &)*ri.m_pItem;
 		HRESULT hRes = fScriptBreak(ri.s_pChars, iLen, &I.m_si.a, ri.s_pLogAttr);
 
@@ -1782,15 +1805,13 @@ bool GR_Win32USPGraphics::canBreak(GR_RenderInfo & ri, UT_sint32 &iNext, bool bA
 		if(RI.s_pLogAttr[ri.m_iOffset].fWhiteSpace)
 			return true;
 
-		// find the next break
-		for(UT_sint32 i = ri.m_iOffset; i < RI.m_iLength; ++i)
-		{
-			if(RI.s_pLogAttr[i].fWhiteSpace)
-			{
-				iNext = i;
-				break;
-			}
-		}
+		// this fixes 9462;
+		bool bBreak = GR_Graphics::canBreak(ri, iNext, bAfter);
+
+		// if the base class gave us a break or indicated where the break is, return
+		if(bBreak || iNext >= 0)
+			return bBreak;
+		
 	}
 	
 	return false;
@@ -2227,7 +2248,7 @@ void GR_Win32USPGraphics::positionToXY(const GR_RenderInfo & ri,
 	x2 = x;
 }
 
-void GR_Win32USPGraphics::drawChars(const UT_UCSChar* pChars,
+void GR_Win32USPGraphics::_drawChars(const UT_UCSChar* pChars,
 									int iCharOffset, int iLength,
 									UT_sint32 xoff, UT_sint32 yoff,
 									int * /*pCharWidth*/)
@@ -2273,7 +2294,8 @@ void GR_Win32USPGraphics::drawChars(const UT_UCSChar* pChars,
 		LOG_USP_EXCPT_X("fScriptStringAnalyse failed", hRes)
 	}
 	
-	hRes = fScriptStringOut(SSA, (UT_sint32)((double)_tduX(xoff) * m_fXYRatio), _tduY(yoff), 0, NULL, 0, 0, FALSE);
+	hRes = fScriptStringOut(SSA, (UT_sint32)((double)_tduX(xoff) * m_fXYRatio), _tduY(yoff),
+							0, NULL, 0, 0, FALSE);
 
 	if(hRes)
 	{
@@ -2288,6 +2310,28 @@ void GR_Win32USPGraphics::drawChars(const UT_UCSChar* pChars,
 		delete [] pwChars;
 }
 
+void GR_Win32USPGraphics::drawChars(const UT_UCSChar* pChars,
+									int iCharOffset, int iLength,
+									UT_sint32 xoff, UT_sint32 yoff,
+									int * pCharWidth)
+{
+	SetTextAlign(m_hdc, TA_LEFT | TA_TOP);
+	_drawChars(pChars, iCharOffset, iLength, xoff, yoff, pCharWidth);
+}
+
+
+void GR_Win32USPGraphics::drawCharsRelativeToBaseline(const UT_UCSChar* pChars,
+								 int iCharOffset,
+								 int iLength,
+								 UT_sint32 xoff,
+								 UT_sint32 yoff,
+								 int* pCharWidths)
+{
+	SetTextAlign(m_hdc, TA_LEFT | TA_BASELINE);
+	_drawChars(pChars, iCharOffset, iLength, xoff, yoff, pCharWidths);
+}
+
+
 void GR_Win32USPGraphics::setZoomPercentage(UT_uint32 iZoom)
 {
 	if(getZoomPercentage() != iZoom)
