@@ -86,7 +86,7 @@ ABI_EXPORT UT_sint32 UT_strnicmp(const char *s1, const char *s2, int ilen);
 
 ABI_EXPORT bool  UT_cloneString(char *& rszDest, const char * szSource);
 ABI_EXPORT bool  UT_replaceString(char *& rszDest, const char * szSource);
-
+ABI_EXPORT size_t  UT_strnlen(const char *s, size_t maxlen);
 ABI_EXPORT char *  UT_upperString(char * string);
 ABI_EXPORT char *  UT_lowerString(char * string);
 
@@ -121,6 +121,10 @@ ABI_EXPORT XML_Char *  UT_XML_transNoAmpersands(const XML_Char * szSource);
 ABI_EXPORT UT_UCSChar  UT_decodeUTF8char(const XML_Char * p, UT_uint32 len);
 ABI_EXPORT void  UT_decodeUTF8string(const XML_Char * p, UT_uint32 len, UT_GrowBuf * pResult);
 ABI_EXPORT XML_Char *  UT_encodeUTF8char(UT_UCSChar cIn);
+ABI_EXPORT bool  UT_isValidUTF8string(const XML_Char * p, UT_uint32 len);
+
+ABI_EXPORT bool  UT_isValidXML(const char *s);
+ABI_EXPORT bool  UT_validXML(char * s);
 
 /* ABI_EXPORT XML_Char *  UT_decodeXMLstring(XML_Char *pcIn);
  * This has moved to ut_xml.cpp as UT_XML::decode ()
