@@ -27,7 +27,10 @@
 #include "xap_QNXDlg_Print.h"
 #include "xap_QNXDlg_MessageBox.h"
 #include "xap_QNXApp.h"
-#include "xap_QNXFrame.h"
+#include "xap_QNXFrameImpl.h"
+#include "xap_Frame.h"
+#include "gr_QNXGraphics.h"
+
 #include "xap_Strings.h"
 
 /*****************************************************************/
@@ -45,7 +48,6 @@ XAP_QNXDialog_Print::XAP_QNXDialog_Print(XAP_DialogFactory * pDlgFactory,
 	: XAP_Dialog_Print(pDlgFactory,id)
 {
 	m_pPrintContext = NULL;
-	m_pQNXFrame = NULL;
 }
 
 XAP_QNXDialog_Print::~XAP_QNXDialog_Print(void)
@@ -85,36 +87,32 @@ void XAP_QNXDialog_Print::useEnd(void)
 GR_Graphics * XAP_QNXDialog_Print::getPrinterGraphicsContext(void)
 {
 	UT_ASSERT(m_answer == a_OK);
-	UT_ASSERT(m_pQNXFrame);
 	UT_ASSERT(m_pPrintContext);
+	XAP_QNXFrameImpl *pQNXFrameImpl = static_cast<XAP_QNXFrameImpl *>(m_pFrame->getFrameImpl());
+	
 
-	GR_QNXGraphics *gr = (GR_QNXGraphics *)m_pQNXFrame->getGraphics();
+	GR_QNXGraphics *gr = (GR_QNXGraphics *)pQNXFrameImpl->getGraphics();
 	gr->setPrintContext(m_pPrintContext);
 
 	/* Return the same graphics as we used for the screen */
-	return m_pQNXFrame->getGraphics();
+	return pQNXFrameImpl->getGraphics();
 }
 
 void XAP_QNXDialog_Print::releasePrinterGraphicsContext(GR_Graphics * pContext)
 {
-	UT_ASSERT(m_pQNXFrame);
 	UT_ASSERT(m_pPrintContext);
+	XAP_QNXFrameImpl *pQNXFrameImpl = static_cast<XAP_QNXFrameImpl *>(m_pFrame->getFrameImpl());
 
-	GR_QNXGraphics *gr = (GR_QNXGraphics *)m_pQNXFrame->getGraphics();
+	GR_QNXGraphics *gr = (GR_QNXGraphics *)pQNXFrameImpl->getGraphics();
 	gr->setPrintContext(NULL);
-/*
-	PpPrintReleasePC(m_pPrintContext);
-	m_pPrintContext = NULL;
-*/
 }
 
 /*****************************************************************/
 
 void XAP_QNXDialog_Print::runModal(XAP_Frame * pFrame)
 {
-	m_pQNXFrame = static_cast<XAP_QNXFrame *>(pFrame);
-	UT_ASSERT(m_pQNXFrame);
-	
+
+	m_pFrame = pFrame;	
 	// see if they just want the properties of the printer without
 	// bothering the user.
 	if (m_bPersistValid && m_bBypassActualDialog) {
@@ -140,15 +138,20 @@ void XAP_QNXDialog_Print::_raisePrintDialog(XAP_Frame * pFrame)
 
 	if (m_pPrintContext) {
 		PpReleasePC(m_pPrintContext);
+		m_pPrintContext = NULL;
 	}
 
 	/*TODO: Map the user choices from persistPrintDlg to the current dialog */
 
 	int value;
 
+	XAP_QNXFrameImpl * pQNXFrameImpl = (XAP_QNXFrameImpl*)pFrame->getFrameImpl();
+	PtWidget_t *parentWindow =	pQNXFrameImpl->getTopLevelWindow();	
+	UT_ASSERT(parentWindow);
+
 	m_pPrintContext = PpCreatePC();
 	UT_ASSERT(m_pPrintContext);
-	value = PtPrintSelection(m_pQNXFrame->getTopLevelWindow(), 		/* Parent widget */
+	value = PtPrintSelection(parentWindow, 		/* Parent widget */
 					 		 NULL, 									/* Position on the screen */
 					 		 NULL, 									/* Title */
 					 		 m_pPrintContext, 						/* Print context */
@@ -168,8 +171,8 @@ void XAP_QNXDialog_Print::_raisePrintDialog(XAP_Frame * pFrame)
 	if (value == Pt_PRINTSEL_PRINT || value == Pt_PRINTSEL_PREVIEW) {
 		UT_uint32 first = 0, last = 0;
 		char *option;
-		PhPoint_t	*gpoint, point;
-		PhRect_t 	*rect, nrect;
+		PhPoint_t	 point;
+		PhRect_t 	nrect;
 		PhDim_t 	*dim, size;
 
 		//TODO: Do we need to specify a source of 72 dpi?
@@ -262,8 +265,8 @@ void XAP_QNXDialog_Print::_raisePrintDialog(XAP_Frame * pFrame)
 				last = m_persistPrintDlg.nMaxPage;
 			}
 			
-			m_nFirstPage = __min(first,last);
-			m_nLastPage = __max(first,last);
+			m_nFirstPage = UT_MIN(first,last);
+			m_nLastPage = UT_MAX(first,last);
 		}
 	}
 }
