@@ -1,5 +1,9 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 #include <stdio.h>
 #include <stdlib.h>
+#include <ctype.h>
+
 #include <glib.h>
 
 #include "xap_UnixEncodingManager.h"
@@ -21,7 +25,7 @@
   C
   ""
   
-  It's much more powerfull (gives correct result) than plain setlocale since 
+  It's much more powerful (gives correct result) than plain setlocale since 
   it explicitly reads locale aliases.
 */
 #ifdef __cplusplus
@@ -103,13 +107,6 @@ read_aliases (char *file)
   fclose (fp);
 }
 
-static void
-free_entry (void *ekey,void *eval, void* user_data)
-{
-  g_free(ekey);
-  g_free(eval);
-}
-
 /*return the un-aliased language as a newly allocated string*/
 static char *
 unalias_lang (char *lang)
@@ -125,9 +122,8 @@ unalias_lang (char *lang)
       read_aliases ("/usr/lib/X11/locale/locale.alias");
       read_aliases ("/usr/openwin/lib/locale/locale.alias");
     }
-
   i = 0;
-  while ((p=(char*)g_hash_table_lookup(alias_table,lang)) && strcmp(p, lang))
+  while ((p=static_cast<char*>(g_hash_table_lookup(alias_table,lang))) && strcmp(p, lang))
     {
       lang = p;
       if (i++ == 30)
@@ -143,7 +139,14 @@ unalias_lang (char *lang)
   return lang;
 }
 
-	
+static void
+free_entry (void *ekey,void *eval,void *user_data)
+{
+g_free(ekey);
+g_free(eval);
+return;
+}
+
 /* Mask for components of locale spec. The ordering here is from
  * least significant to most significant
  */
@@ -268,34 +271,34 @@ compute_locale_variants (const gchar *locale)
 static const gchar *
 guess_category_value (const gchar *categoryname)
 {
-  const gchar *retval;
+	const gchar *retval;
 
-  /* The highest priority value is the `LANGUAGE' environment
-     variable.  This is a GNU extension.  */
-  retval = g_getenv ("LANGUAGE");
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+	/* The highest priority value is the `LANGUAGE' environment
+		 variable.  This is a GNU extension.  */
+	retval = g_getenv ("LANGUAGE");
+	if (retval != NULL && retval[0] != '\0')
+		return retval;
 
-  /* `LANGUAGE' is not set.  So we have to proceed with the POSIX
-     methods of looking to `LC_ALL', `LC_xxx', and `LANG'.  On some
-     systems this can be done by the `setlocale' function itself.  */
+	/* `LANGUAGE' is not set.  So we have to proceed with the POSIX
+		 methods of looking to `LC_ALL', `LC_xxx', and `LANG'.  On some
+		 systems this can be done by the `setlocale' function itself.  */
 
-  /* Setting of LC_ALL overwrites all other.  */
-  retval = g_getenv ("LC_ALL");  
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+	/* Setting of LC_ALL overwrites all other.  */
+	retval = g_getenv ("LC_ALL");
+	if (retval != NULL && retval[0] != '\0')
+		return retval;
 
-  /* Next comes the name of the desired category.  */
-  retval = g_getenv (categoryname);
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+	/* Next comes the name of the desired category.  */
+	retval = g_getenv (categoryname);
+	if (retval != NULL && retval[0] != '\0')
+		return retval;
 
-  /* Last possibility is the LANG environment variable.  */
-  retval = g_getenv ("LANG");
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+	/* Last possibility is the LANG environment variable.  */
+	retval = g_getenv ("LANG");
+	if (retval != NULL && retval[0] != '\0')
+		return retval;
 
-  return NULL;
+	return NULL;
 }
 
 /**
@@ -315,16 +318,16 @@ g_i18n_get_language_list (const gchar *category_name)
 {
   GList *list;
   prepped_table = 0;
-  
-  if (!category_name)
-    category_name= "LC_ALL";
 
-  if (category_table)
+	if (!category_name)
+		category_name= "LC_ALL";
+
+	if (category_table)
     {
 #if 0
-	  // we want a fresh reading of the LANG variable every time so we can
-	  // work out the 8bit encoding under utf-8 locale
-      list= (GList *)g_hash_table_lookup (category_table, (const gpointer) category_name);
+		// we want a fresh reading of the LANG variable every time so we can
+		// work out the non-Unicode encoding under UTF-8 locale
+		list= static_cast<GList *>(g_hash_table_lookup (category_table, const_cast<const gpointer>(category_name)));
 #else
 		xxx_UT_DEBUGMSG(("recreating hash table\n"));
 		g_hash_table_destroy (category_table);
@@ -333,66 +336,64 @@ g_i18n_get_language_list (const gchar *category_name)
 		
 #endif
     }
-  else
+	else
     {
-      category_table= g_hash_table_new (g_str_hash, g_str_equal);
-      list= NULL;
+		category_table= g_hash_table_new (g_str_hash, g_str_equal);
+		list= NULL;
     }
 
-  if (!list)
+	if (!list)
     {
-      gint c_locale_defined= FALSE;
-  
-      const gchar *category_value;
-      gchar *category_memory, *orig_category_memory;
-
-      category_value = guess_category_value (category_name);
-      if (! category_value)
-	category_value = "C";
-      orig_category_memory = category_memory =
-	(gchar*) g_malloc (strlen (category_value)+1);
-      
-      while (category_value[0] != '\0')
-	{
-	  while (category_value[0] != '\0' && category_value[0] == ':')
-	    ++category_value;
+		gint c_locale_defined= FALSE;
 	  
-	  if (category_value[0] != '\0')
-	    {
-	      char *cp= category_memory;
-	      
-	      while (category_value[0] != '\0' && category_value[0] != ':')
-		*category_memory++= *category_value++;
-	      
-	      category_memory[0]= '\0'; 
-	      category_memory++;
-	      
-	      cp = unalias_lang(cp);
+		const gchar *category_value;
+		gchar *category_memory, *orig_category_memory;
 
-	      
-	      if (strcmp (cp, "C") == 0)
-		c_locale_defined= TRUE;
-	      
-	      list= g_list_concat (list, compute_locale_variants (cp));
-	    }
-	}
-
-      g_free (orig_category_memory);
+		category_value = guess_category_value (category_name);
+		if (! category_value)
+			category_value = "C";
+		orig_category_memory = category_memory =
+			static_cast<gchar*>(g_malloc (strlen (category_value)+1));
       
-      if (!c_locale_defined)
-	list= g_list_append (list, (void*)"C");
+		while (category_value[0] != '\0')
+		{
+			while (category_value[0] != '\0' && category_value[0] == ':')
+				++category_value;
+	  
+			if (category_value[0] != '\0')
+			{
+				char *cp= category_memory;
+	      
+				while (category_value[0] != '\0' && category_value[0] != ':')
+					*category_memory++= *category_value++;
+	      
+				category_memory[0]= '\0'; 
+				category_memory++;
+				  
+				cp = unalias_lang(cp);
+				  
+				if (strcmp (cp, "C") == 0)
+					c_locale_defined= TRUE;
+	      
+				list= g_list_concat (list, compute_locale_variants (cp));
+			}
+		}
 
-      g_hash_table_insert (category_table, (gpointer) category_name, list);
+		g_free (orig_category_memory);
+      
+		if (!c_locale_defined)
+			list= g_list_append (list, reinterpret_cast<void*>(const_cast<gchar *>("C")));
+
+		g_hash_table_insert (category_table, reinterpret_cast<gpointer>(const_cast<gchar *>(category_name)), list);
     }
 
-     g_hash_table_foreach(alias_table, free_entry, NULL);
-     g_hash_table_destroy(alias_table);
-     prepped_table = 0;  
-   
+   g_hash_table_foreach(alias_table, free_entry, NULL);
+   g_hash_table_destroy(alias_table);  
+   prepped_table = 0;
+
   return list;
 }
 
-
 /************************************************************/
 
 XAP_EncodingManager *XAP_EncodingManager::get_instance()
@@ -410,140 +411,177 @@ XAP_EncodingManager *XAP_EncodingManager::get_instance()
 
 /************************************************************/
 
+static UT_UTF8String NativeEncodingName;
+static UT_UTF8String NativeSystemEncodingName;
+static UT_UTF8String Native8BitEncodingName;
+static UT_UTF8String NativeNonUnicodeEncodingName;
+static UT_UTF8String NativeUnicodeEncodingName;
+static UT_UTF8String LanguageISOName;
+static UT_UTF8String LanguageISOTerritory;
+
 XAP_UnixEncodingManager::XAP_UnixEncodingManager() 
 {
 }
 
-XAP_UnixEncodingManager::~XAP_UnixEncodingManager()
+XAP_UnixEncodingManager::~XAP_UnixEncodingManager() 
 {
 }
 
-static const char * NativeEncodingName;
-static const char * NativeUnicodeEncodingName;
-static const char * Native8BitEncodingName;
-static const char * LanguageISOName;
-static const char * LanguageISOTerritory;
-
 const char* XAP_UnixEncodingManager::getNativeEncodingName() const
 {     
-  return NativeEncodingName; 
+  return NativeEncodingName.utf8_str(); 
 }
 
-const char* XAP_UnixEncodingManager::getNativeUnicodeEncodingName() const
+const char* XAP_UnixEncodingManager::getNativeSystemEncodingName() const
 {     
-  return NativeEncodingName; 
+  return NativeSystemEncodingName.utf8_str(); 
 }
 
 const char* XAP_UnixEncodingManager::getNative8BitEncodingName() const
 {     
-  return Native8BitEncodingName;
+  return Native8BitEncodingName.utf8_str();
+}
+
+const char* XAP_UnixEncodingManager::getNativeNonUnicodeEncodingName() const
+{     
+  return NativeNonUnicodeEncodingName.utf8_str();
+}
+
+const char* XAP_UnixEncodingManager::getNativeUnicodeEncodingName() const
+{     
+  return NativeUnicodeEncodingName.utf8_str(); 
 }
 
 const char* XAP_UnixEncodingManager::getLanguageISOName() const
 {
- 	return LanguageISOName; 
+ 	return LanguageISOName.utf8_str(); 
 }
 
 const char* XAP_UnixEncodingManager::getLanguageISOTerritory() const
 { 	
-  return LanguageISOTerritory; 
+  return LanguageISOTerritory.utf8_str(); 
 }
 
 void  XAP_UnixEncodingManager::initialize()
 {	
 	const GList* lst = g_i18n_get_language_list ("LANG");
-	const char* locname = (char*)lst->data;
-	
-	NativeEncodingName = "ISO-8859-1";
-	Native8BitEncodingName = "ISO-8859-1";
+	const char* locname = static_cast<char*>(lst->data);
+
+	NativeEncodingName =  "ISO-8859-1";
+	NativeSystemEncodingName =
+	Native8BitEncodingName =
+	NativeNonUnicodeEncodingName = NativeEncodingName;
 	NativeUnicodeEncodingName = "UTF-8";
 	LanguageISOName = "en";
-	LanguageISOTerritory = "US";
-	
+	LanguageISOTerritory = "US";   
+
 	if (!*locname || !strcmp(locname,"C"))
 	{ 	/* paranoic case - broken system */
 		; /*already initialized*/
 	}
 	else
 	{
-		char* lang,*terr,*cs,*mod;
+		char * lang = NULL;
+		char * terr = NULL;
+		char * cs   = NULL;
+		char * mod  = NULL;
+
 		int mask = explode_locale (locname,&lang,&terr,&cs,&mod);
+
 		LanguageISOName = lang;
-		if (mask & COMPONENT_TERRITORY)
+
+		if ((mask & COMPONENT_TERRITORY) && terr)
 		{
-			LanguageISOTerritory = terr+1;/*yes, +1*/
+			LanguageISOTerritory = terr + 1; /* yes, +1 */
 		}
-		if (mask & COMPONENT_CODESET)
+		if ((mask & COMPONENT_CODESET) && cs)
 		{
-			NativeEncodingName = cs+1;
-			if (!strncmp(cs+1,"ISO8859",strlen("ISO8859"))) {
-				/*
-			 	work around glibc bug - its iconv doesn't know
-			 	ISO8859-* - ISO-8859-1 should be used (we encounter this 
-			 	since locale.alias aliases en_US.ISO8859-1 to 'en'
-			 	PS: This is true for my RH6.0 system - VH
-				*/
-				static char buf[40];
-				strcpy(buf,"ISO-");
-				strcat(buf,cs+1+3);
-				NativeEncodingName = buf;
+			if (cs[1])
+			{
+				int length = strlen (cs + 1);
+				char * name = static_cast<char *>(malloc (length + 3));
+				if (name)
+				{
+					strcpy (name, cs + 1);
+					
+					/* make the encoding name upper-case
+					 * TODO why not use the UT_islower/UT_isupper?
+					 */
+					for (int i = 0; i < length; i++)
+						if (islower (static_cast<int>(static_cast<unsigned char>(name[i]))))
+							name[i] = static_cast<char>(toupper (static_cast<int>(static_cast<unsigned char>(name[i]))));
+					
+					/* encoding names may be presented as iso88591 or ISO8859-1,
+					 * but we need both hyphens for iconv
+					 */
+					if (strncmp (name, "ISO8859", 7) == 0)
+					{
+						memmove (name + 4, name + 3, length + 1 - 3);
+						length++;
+						name[3] = '-';
+						if (name[8] != '-')
+						{
+							memmove (name + 9, name + 8, length + 1 - 8);
+							length++;
+							name[8] = '-';
+						}
+					}
+					NativeEncodingName = name;
+					FREEP(name);
+				}
 			}
-			Native8BitEncodingName = NativeEncodingName;
+			Native8BitEncodingName = NativeSystemEncodingName = NativeEncodingName;
 			
-			// need to get 8bit encoding if encoding is utf-8
-			if(!strcmp(NativeEncodingName, "utf-8") || !strcmp(NativeEncodingName, "UTF-8"))
+			// need to get non-unicode encoding if encoding is UTF-8
+			if(!UT_stricmp(NativeEncodingName.utf8_str(), "UTF-8"))
 			{
 				// we want to get the encoding that would be used for the given
-				// language/territory if the utf-8 encoding was not specified
+				// language/territory if the UTF-8 encoding was not specified
 				// by LANG
-
-			  UT_String OLDLANG (getenv("LANG"));
+				
+				UT_UTF8String OLDLANG (getenv("LANG"));
 #if defined(SETENV_MISSING) 
-			  UT_String MYLANG ("LANG=");
-			  
-			  MYLANG += LanguageISOName;
-			  MYLANG += "_";
-			  MYLANG += LanguageISOTerritory;
-			  putenv(MYLANG.c_str());
+				UT_UTF8String MYLANG ("LANG=");
+				
+				MYLANG += LanguageISOName;
+				MYLANG += "_";
+				MYLANG += LanguageISOTerritory;
+				putenv(MYLANG.utf8_str());
 #else
-			  UT_String MYLANG (LanguageISOName);
-			  MYLANG += "_";
-			  MYLANG += LanguageISOTerritory;
-			  setenv ("LANG", MYLANG.c_str(), 1);
+				UT_UTF8String MYLANG (LanguageISOName);
+				MYLANG += "_";
+				MYLANG += LanguageISOTerritory;
+				setenv ("LANG", MYLANG.utf8_str(), 1);
 #endif
-	           	   const GList* my_lst = g_i18n_get_language_list ("LANG");
-			   const char* my_locname = (char*)my_lst->data;
-			   
-			   char *my_lang,*my_terr,*my_cs,*my_mod;
-			   int my_mask = explode_locale (my_locname,&my_lang,&my_terr,&my_cs,&my_mod);
-			
 				if (mask & COMPONENT_CODESET)
 				{
-					Native8BitEncodingName = my_cs+1;
-					xxx_UT_DEBUGMSG(("Native8BitEncodingName (1) %s\n", Native8BitEncodingName));
-					if (!strncmp(my_cs+1,"ISO8859",strlen("ISO8859")))
+					NativeNonUnicodeEncodingName = cs+1;
+					xxx_UT_DEBUGMSG(("NativeNonUnicodeEncodingName (1) %s\n", NativeNonUnicodeEncodingName));
+					if (!strncmp(cs+1,"ISO8859",strlen("ISO8859")))
 					{
-						static char buf[40];
+						char buf[40];
 						strcpy(buf,"ISO-");
-						strcat(buf,my_cs+1+3);
-						Native8BitEncodingName = buf;
+						strcat(buf,cs+1+3);
+						NativeNonUnicodeEncodingName = buf;
 					}
-					xxx_UT_DEBUGMSG(("Native8BitEncodingName (2) %s\n", Native8BitEncodingName));
-				
+					xxx_UT_DEBUGMSG(("NativeNonUnicodeEncodingName (2) %s\n", NativeNonUnicodeEncodingName));
 				}
-
 #if defined(SETENV_MISSING)
 				MYLANG = "LANG=";
 				MYLANG += OLDLANG;
-				putenv(MYLANG.c_str());
+				putenv(MYLANG.utf8_str());
 #else
-				setenv("LANG", OLDLANG.c_str(), 1);
+				setenv("LANG", OLDLANG.utf8_str(), 1);
 #endif			
 			}
+			
 		}
-	};	
-	XAP_EncodingManager::initialize();
+		FREEP(lang);
+		FREEP(terr);
+		FREEP(cs);
+		FREEP(mod);
+	}
+	// Moved to end so that we correctly detect if the locale is CJK.
+	XAP_EncodingManager::initialize(); 
 	describe();
-};
-
-
+}
