@@ -71,6 +71,8 @@ XAP_Win32Slurp::XAP_Win32Slurp(XAP_Win32App * pApp)
 	m_pApp = pApp;
 	m_bInitialized = false;
 	s_Slurp = this;
+	m_hszServerName = NULL;
+	m_hszTopic = NULL;
 }
 
 XAP_Win32Slurp::~XAP_Win32Slurp(void)
@@ -152,7 +154,7 @@ bool XAP_Win32Slurp::connectSlurper(void)
 	// the "TopicName" must match the value in the key:
 	// HKEY_CLASSES_ROOT\<xxx>\shell\open\ddeexec\topic
 	
-	m_hszServerName = DdeCreateStringHandle(m_idDdeServerInst, m_pApp->getApplicationName(), CP_WINANSI);
+	m_hszServerName = DdeCreateStringHandle(m_idDdeServerInst, const_cast<char *>(m_pApp->getApplicationName()), CP_WINANSI);
 	m_hszTopic = DdeCreateStringHandle(m_idDdeServerInst, MY_DDE_TOPICNAME, CP_WINANSI);
 
 	// register the server Name
@@ -185,7 +187,7 @@ void XAP_Win32Slurp::processCommand(HDDEDATA hData)
 {
 	DWORD bufSize = DdeGetData(hData,NULL,0,0);
 
-	char * pBuf = (char *)calloc(sizeof(char),bufSize+100);
+	char * pBuf = (char *)UT_calloc(sizeof(char),bufSize+100);
 	if (!pBuf)
 	{
 		UT_DEBUGMSG(("No memory to allocate DDE buffer [size %d]\n",bufSize));
@@ -325,12 +327,12 @@ void XAP_Win32Slurp::stuffRegistry(const char * szSuffix,
 	// HKEY_CLASSES_ROOT\<foo>\shell\open\ddeexec = [Open("%1")]
 	// HKEY_CLASSES_ROOT\<foo>\shell\open\ddeexec\application = <application_name>
 	// HKEY_CLASSES_ROOT\<foo>\shell\open\ddeexec\topic = System
-	// HKEY_CLASSES_ROOT\<foo>\DefaultIcon = <exe_pathname,1>
+	// HKEY_CLASSES_ROOT\<foo>\DefaultIcon = <exe_pathname,2>
 
 #define VALUE_DDEEXEC_OPEN			"[Open(\"%1\")]"
 #define FORMAT_OUR_INDIRECTION		"AbiSuite.%s"
 #define CONTENT_TYPE_KEY			"Content Type"
-#define DOCUMENT_ICON_POSITION	3
+#define DOCUMENT_ICON_POSITION	2
 #define xx(s)					((LPBYTE)(s)),(strlen(s)+1)
 	
 	char buf[1024];
