@@ -217,6 +217,7 @@ bool XAP_PrefsScheme::getNthValue(UT_uint32 k, const XML_Char ** pszKey, const X
 		*pszValue = NULL;
 		return false;
 	}
+	return false;
 }
 
 /*****************************************************************/
@@ -434,15 +435,15 @@ void XAP_Prefs::log(const char * where, const char * what, XAPPrefsLog_Level lev
 		default:
 			*s += "message: ";
 	}
+
+	sWhere.escapeXML();
+	sWhat.escapeXML();
 	
 	*s += sWhere;
 	*s += " - ";
 	*s += sWhat;
 	*s += " -->";
 
-	// s->escapeXML(); // since we embed these as comments we do not
-	                   // have to do this
-
 	m_vecLog.addItem(s);
 }
 
