@@ -111,6 +111,10 @@ public:
 	virtual void	      updateScreen(bool bDirtyRunsOnly=true) = 0;
 	virtual GR_Graphics * getGraphics(void) const = 0;
     virtual void          updateLayout(void) = 0;
+	virtual void          rebuildLayout(void) = 0;
+	virtual void          remeasureCharsWithoutRebuild() = 0;
+	virtual void          fontMetricsChange() = 0;
+	
 	virtual void	cmdScroll(AV_ScrollCmd cmd, UT_uint32 iPos = 0) = 0;
 	void			addScrollListener(AV_ScrollObj*);
 	void			removeScrollListener(AV_ScrollObj*);
@@ -124,7 +128,7 @@ public:
 
 	//! returns true iff the current view is the active/focused window
 	bool			isActive(void);
-	virtual bool	notifyListeners(const AV_ChangeMask hint) = 0;
+	virtual bool	notifyListeners(const AV_ChangeMask hint, void * pPrivateData = NULL);
 	virtual bool    isDocumentPresent(void) = 0;
 	virtual bool	canDo(bool bUndo) const = 0;
 	virtual void	cmdUndo(UT_uint32 count) = 0;
@@ -155,8 +159,6 @@ public:
 	virtual void setCursorWait(void) = 0;
 	virtual void clearCursorWait(void) = 0;
 
-	virtual void remeasureChars(void) = 0;
-	
 protected:
 	XAP_App *			m_pApp;
 	void*				m_pParentData;
