@@ -34,6 +34,7 @@
 #include "fl_Squiggles.h"
 #include "fl_AutoNum.h"
 #include "fp_Page.h"
+#include "fp_Line.h"
 #include "fp_TextRun.h"
 #include "fp_Run.h"
 #include "fv_View.h"
@@ -588,6 +589,53 @@ void FL_DocLayout::fillLayouts(void)
 			}
 		}
 	}
+	if(m_pView)
+	{
+	        fl_DocSectionLayout * pLastSec = getLastSection();
+		fl_ContainerLayout * pCL = pLastSec->getLastLayout();
+		fl_BlockLayout * pBL = NULL;
+		bool bRebreak = false;
+		if(pCL->getContainerType() == FL_CONTAINER_BLOCK)
+		{
+	              pBL = static_cast<fl_BlockLayout *>(pCL);
+		}
+		else
+		{
+	              pBL = pCL->getPrevBlockInDocument();
+		}
+		if(pBL)
+		{
+		      fp_Line * pLine = static_cast<fp_Line *>(pBL->getLastContainer());
+		      if(pLine == NULL)
+		      {
+			    bRebreak = true;
+		      }
+		      else if(pLine->getPage() == NULL)
+		      {
+			    bRebreak = true;
+		      }
+		      else
+		      {
+			    fp_Page * pPage = getFirstPage();
+			    while(pPage && pPage != pLine->getPage())
+			    {
+			         pPage = pPage->getNext();
+			    }
+			    if(pLine->getPage() != pPage)
+			    {
+			         bRebreak = true;
+			    }
+			    if(pLine->getPage() == getFirstPage())
+			    {
+				bRebreak = true;
+			    }
+		      }
+		}
+		if(bRebreak)
+		{
+		      getFirstSection()->completeBreakSection();
+		}
+	}
 }
 
 
