@@ -20,6 +20,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include "ap_Features.h"
 #include "ut_types.h"
 #include "ut_assert.h"
 #include "ut_string.h"
@@ -44,6 +45,7 @@
 #include "ie_mailmerge.h"
 #include "fp_TableContainer.h"
 #include "fl_BlockLayout.h"
+#include "pp_AttrProp.h"
 
 #ifdef _WIN32
 #include "ap_Win32App.h" 
@@ -54,107 +56,6 @@
 /*****************************************************************/
 /*****************************************************************/
 
-Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Autotext)
-{
-	XAP_App * pApp = XAP_App::getApp();
-	UT_return_val_if_fail (pApp && pLabel, NULL);
-
-	const char * c = NULL;
-
-	const XAP_StringSet * pss = pApp->getStringSet();
-	static UT_UTF8String s;
-	pss->getValueUTF8(AP_STRING_ID_DLG_Spell_NoSuggestions,s);
-
-	switch (id)
-	  {
-	  case AP_MENU_ID_AUTOTEXT_ATTN_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_ATTN_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_ATTN_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_ATTN_2, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_4, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_5:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_5, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_6:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_6, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_7:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_7, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_8:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_8, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_9:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_9, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_10:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_10, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_11:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_11, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_12:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_12, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_MAIL_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_4, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_5:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_5, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_6:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_6, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_7:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_7, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_8:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_8, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_REFERENCE_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_REFERENCE_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_REFERENCE_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_REFERENCE_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_REFERENCE_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_REFERENCE_3, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_4, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_SUBJECT_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SUBJECT_1, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_4, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_5:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_5, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_6:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_6, s); break;
-
-	  default:
-	    c = "No clue"; break;
-	  }
-
-	if(!c) 	c = s.utf8_str();
-
-	return c;
-}
-
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Toolbar)
 {
 	XAP_App * pApp = XAP_App::getApp();
@@ -192,7 +93,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Recent)
 	UT_return_val_if_fail (pApp && pLabel, NULL);
 
 	UT_ASSERT_HARMLESS(id >= AP_MENU_ID_FILE_RECENT_1);
-	UT_ASSERT_HARMLESS(id <= AP_MENU_ID_FILE_RECENT_9);
 
 	UT_uint32 ndx = (id - AP_MENU_ID_FILE_RECENT_1 + 1);
 
@@ -288,24 +188,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Search)
 	return buf;
 }
 
-Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_AboutOS)
-{
-	// Compute the menu label for the about OS help item.
-
-	XAP_App * pApp = XAP_App::getApp();
-	UT_return_val_if_fail (pApp && pLabel, NULL);
-
-	UT_ASSERT_HARMLESS(id == AP_MENU_ID_HELP_ABOUTOS);
-
-	const char * szFormat = pLabel->getMenuLabel();
-	static char buf[128];
-
-	const char * szAppName = pApp->getApplicationName();
-
-	sprintf(buf,szFormat,szAppName);
-	return buf;
-}
-
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Checkver)
 {
 	// Compute the menu label for the about the check version item.
@@ -610,7 +492,24 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_HyperlinkOK)
 	    s = EV_MIS_Gray ;
 		return s;
 	}
-
+	if(pBL1->getLength() == 1)
+	{
+	    s = EV_MIS_Gray ;
+	    return s;
+	}
+	PT_DocPosition posTemp =0;
+	if(posStart > posEnd)
+	{
+	  posTemp = posStart;
+	  posStart = posEnd;
+	  posEnd = posStart;
+	}
+	if(posStart < pBL1->getPosition(true))
+	{
+	    s = EV_MIS_Gray ;
+	    return s;
+	}
+	  
 	return s ;
 }
 
@@ -724,11 +623,11 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Changes)
 	switch(id)
 	{
 	case AP_MENU_ID_FILE_SAVE:
-	  if (!pView->getDocument()->isDirty() || !pView->canDo(true))
+		if (!pView->getDocument()->isDirty() /*|| !pView->canDo(true)*/) // this caused bug 7580
 	    s = EV_MIS_Gray;
 	  break;
 	case AP_MENU_ID_FILE_REVERT:
-	  if (!pView->getDocument()->isDirty() || !pView->canDo(true))
+		if (!pView->getDocument()->isDirty() /*|| !pView->canDo(true)*/) // this cause bug 7580
 	    s = EV_MIS_Gray;
 	  break;
 	case AP_MENU_ID_EDIT_UNDO:
@@ -772,17 +671,17 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Changes)
 		break;
 
 	case AP_MENU_ID_TABLE_INSERT:
-		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()))
+		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()) || pView->isInHdrFtr(pView->getSelectionAnchor()) )
 			s = EV_MIS_Gray;
 		break;
 
 	case AP_MENU_ID_TABLE_INSERT_TABLE:
-		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()))
+		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()) || pView->isInHdrFtr(pView->getSelectionAnchor()) )
 			s = EV_MIS_Gray;
 		break;
 
 	case AP_MENU_ID_TABLE_INSERTTABLE:
-		if (pView->isHdrFtrEdit()  || pView->isInHdrFtr(pView->getPoint()))
+		if (pView->isHdrFtrEdit()  || pView->isInHdrFtr(pView->getPoint()) || pView->isInHdrFtr(pView->getSelectionAnchor()) )
 			s = EV_MIS_Gray;
 		break;
 
@@ -822,11 +721,11 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Selection)
 	{
 	case AP_MENU_ID_FMT_LANGUAGE:
 	case AP_MENU_ID_EDIT_CUT:
+	case AP_MENU_ID_EDIT_LATEXEQUATION:
 	case AP_MENU_ID_EDIT_COPY:
 		if (pView->isSelectionEmpty())
 			s = EV_MIS_Gray;
 		break;
-
 	default:
 		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 		break;
@@ -1093,6 +992,97 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_BlockFmt)
 	return s;
 }
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_DocFmt)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	EV_Menu_ItemState s = EV_MIS_ZERO;
+
+	PD_Document * pDoc = pView->getDocument();
+	UT_return_val_if_fail( pDoc, EV_MIS_Gray );
+
+	const PP_AttrProp * pAP = pDoc->getAttrProp();
+	UT_return_val_if_fail( pAP, EV_MIS_Gray );
+	
+	const XML_Char * prop = NULL;
+	const XML_Char * val  = NULL;
+
+	if(pDoc->areStylesLocked()) {
+	    return EV_MIS_Gray;
+	}
+
+	switch(id)
+	{
+		case AP_MENU_ID_FMT_DIRECTION_DOCD_RTL:
+			prop = "dom-dir";
+			val  = "rtl";
+			break;
+
+		default:
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			break;
+	}
+
+	if (prop && val)
+	{
+		const XML_Char * sz;
+
+		if (!pAP->getProperty(prop, sz))
+			return s;
+
+		if (sz && (0 == UT_strcmp(sz, val)))
+			s = EV_MIS_Toggled;
+	}
+
+	return s;
+}
+
+Defun_EV_GetMenuItemState_Fn(ap_GetState_SectFmt)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	EV_Menu_ItemState s = EV_MIS_ZERO;
+
+	const XML_Char * prop = NULL;
+	const XML_Char * val  = NULL;
+
+	if(pView->getDocument()->areStylesLocked()) {
+	    return EV_MIS_Gray;
+	}
+
+	switch(id)
+	{
+		case AP_MENU_ID_FMT_DIRECTION_SD_RTL:
+			prop = "dom-dir";
+			val  = "rtl";
+			break;
+
+		default:
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			break;
+	}
+
+	if (prop && val)
+	{
+		// get current font info from pView
+		const XML_Char ** props_in = NULL;
+		const XML_Char * sz;
+
+		if (!pView->getSectionFormat(&props_in))
+			return s;
+
+		sz = UT_getAttribute(prop, props_in);
+		if (sz && (0 == UT_strcmp(sz, val)))
+			s = EV_MIS_Toggled;
+
+		free(props_in);
+	}
+
+	return s;
+}
+
 Defun_EV_GetMenuItemState_Fn(ap_GetState_View)
 {
 	ABIWORD_VIEW;
@@ -1114,6 +1104,8 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_View)
 	case AP_MENU_ID_VIEW_RULER:
 		if ( pFrameData->m_bShowRuler && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
+		else if( pFrameData->m_bIsFullScreen )
+			s = EV_MIS_Gray;
 		else
 			s = EV_MIS_ZERO;
 		break;
@@ -1132,24 +1124,32 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_View)
 	case AP_MENU_ID_VIEW_TB_1:
 		if ( pFrameData->m_bShowBar[0] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
+		else if( pFrameData->m_bIsFullScreen )
+			s = EV_MIS_Gray;
 		else
 			s = EV_MIS_ZERO;
 		break;
 	case AP_MENU_ID_VIEW_TB_2:	
 		if ( pFrameData->m_bShowBar[1] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
+		else if( pFrameData->m_bIsFullScreen )
+			s = EV_MIS_Gray;
 		else
 			s = EV_MIS_ZERO;
 		break;
 	case AP_MENU_ID_VIEW_TB_3:	
 		if ( pFrameData->m_bShowBar[2] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
+		else if( pFrameData->m_bIsFullScreen )
+			s = EV_MIS_Gray;
 		else
 			s = EV_MIS_ZERO;
 		break;
 	case AP_MENU_ID_VIEW_TB_4:	
 		if ( pFrameData->m_bShowBar[3] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
+		else if( pFrameData->m_bIsFullScreen )
+			s = EV_MIS_Gray;
 		else
 			s = EV_MIS_ZERO;
 		break;
@@ -1167,6 +1167,8 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_View)
               if ( pFrameData->m_bShowStatusBar &&
 				   !pFrameData->m_bIsFullScreen )
 				  s = EV_MIS_Toggled;
+			  else if( pFrameData->m_bIsFullScreen )
+				  s = EV_MIS_Gray;
 			  else
 				  s = EV_MIS_ZERO;
 			  break;
@@ -1233,7 +1235,7 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_History)
     return EV_MIS_ZERO;
 }
 
-Defun_EV_GetMenuItemState_Fn(ap_GetState_MarkRevisions)
+Defun_EV_GetMenuItemState_Fn(ap_GetState_MarkRevisionsCheck)
 {
 	ABIWORD_VIEW;
 	UT_return_val_if_fail (pView, EV_MIS_Gray);
@@ -1251,6 +1253,24 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_MarkRevisions)
     return EV_MIS_ZERO;
 }
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_MarkRevisions)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	if(pView->getDocument()->isAutoRevisioning())
+	{
+		return EV_MIS_Gray;
+	}
+
+	if(pView->isMarkRevisions())
+	{
+		return EV_MIS_ZERO;
+	}
+
+    return EV_MIS_Gray;
+}
+
 Defun_EV_GetMenuItemState_Fn(ap_GetState_RevisionsSelectLevel)
 {
 	ABIWORD_VIEW;
@@ -1425,6 +1445,47 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_InTable)
     return EV_MIS_Gray;
 }
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_PointInTable)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	if(pView->isInTable(pView->getPoint()))
+		return EV_MIS_ZERO;
+
+    return EV_MIS_Gray;
+}
+
+Defun_EV_GetMenuItemState_Fn(ap_GetState_PointOrAnchorInTable)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+	bool bP = pView->isInTable(pView->getPoint());
+	bool bA = pView->isInTable(pView->getSelectionAnchor());
+	if(bP || bA)
+		return EV_MIS_ZERO;
+
+    return EV_MIS_Gray;
+}
+
+
+Defun_EV_GetMenuItemState_Fn(ap_GetState_InTableIsRepeat)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	if(pView->isInTable())
+	{
+	        fp_CellContainer * pCCon = pView->getCellAtPos(pView->getPoint());
+		if(pCCon && pCCon->isRepeated())
+	        {
+		     return EV_MIS_ZERO;
+		}
+		return EV_MIS_Gray;
+	}
+    return EV_MIS_Gray;
+}
+
 
 Defun_EV_GetMenuItemState_Fn(ap_GetState_TableOK)
 {
@@ -1435,6 +1496,10 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_TableOK)
 	{
 		return EV_MIS_Gray;
 	}
+	else if( !pView->isSelectionEmpty() &&  pView->isInTable(pView->getPoint()) && pView->isHdrFtrEdit() )
+	{
+		return EV_MIS_Gray;
+	}
 	else if(pView->isInFootnote())
 	{
 		return EV_MIS_Gray;
@@ -1508,9 +1573,47 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_InImage)
 	{
 		return EV_MIS_ZERO;
 	}
+	if(pView->getFrameEdit()->isActive())
+	{
+	        fl_FrameLayout * pFL = pView->getFrameLayout();
+		if(pFL && pFL->getFrameType() == FL_FRAME_TEXTBOX_TYPE)
+		{
+		        return EV_MIS_Gray;
+		}
+		return EV_MIS_ZERO;
+	}
 	return EV_MIS_Gray;
 }
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_SetPosImage)
+{
+        ABIWORD_VIEW;
+  	UT_return_val_if_fail (pView, EV_MIS_Gray);
+	bool bCont= false;
+	if(pView->isImageSelected())
+	{
+		bCont = true;
+	}
+	if(!bCont & pView->getFrameEdit()->isActive())
+	{
+	        fl_FrameLayout * pFL = pView->getFrameLayout();
+		if(pFL && pFL->getFrameType() == FL_FRAME_TEXTBOX_TYPE)
+		{
+		        return EV_MIS_Gray;
+		}
+		bCont = true;
+	}
+	if(!bCont)
+	{
+	  return EV_MIS_Gray;
+	}
+	if(pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()))
+	{
+		return EV_MIS_Gray;
+	}
+	return EV_MIS_ZERO;
+}
+
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InFrame)
 {
 	ABIWORD_VIEW;
