@@ -64,5 +64,8 @@ typedef UT_sint32 IEGraphicFileType;
 #define IE_IMPEXPNAME_XHTML		"AbiWord::HTML (XHTML)"
 #define IE_IMPEXPNAME_PHTML		"AbiWord::HTML (XHTML+PHP)"
 #define IE_IMPEXPNAME_MHTML		"AbiWord::HTML/multipart"
+#define IE_IMPEXPNAME_MATHML    "AbiWord::MathML"
+#define IE_IMPEXPNAME_GOCHART   "AbiWord::GNOME Office Chart"
+#define IE_IMPEXPNAME_GOCOMPONENT   "AbiWord::GNOME Office Component"
 
 #endif /* IE_TYPES_H */
