@@ -1155,7 +1155,7 @@ private:
   UT_UTF8String m_curStyleName;
 
   UT_GenericVector<XML_Char*>	m_vecInlineFmt;
-  UT_Stack		m_stackFmtStartIndex;
+  UT_NumberStack		m_stackFmtStartIndex;
   const OpenWriter_StylesStream_Listener * m_pSSListener;
 
   UT_uint32 m_imgCnt;
@@ -1201,7 +1201,7 @@ public:
 	if (abi_sty) {
 	  // append an empty paragraph with this one char
 	  if (abi_sty->getColBreakBefore () || abi_sty->getPageBreakBefore ()) {
-	    getDocument()->appendStrux(PTX_Block, NULL);
+	    _insureInBlock(NULL);
 	    UT_UCSChar ucs = (abi_sty->getColBreakBefore () ? UCS_VTAB : UCS_FF);
 	    getDocument()->appendSpan (&ucs, 1);
 	  }
@@ -1233,10 +1233,15 @@ public:
 	const XML_Char * abi_sty = _mapStyle(oo_sty);
 
 	const XML_Char * props[3];
-	props[0] = "props";
-	props[1] = abi_sty;
-	props[2] = 0;
-	
+
+	if(abi_sty && *abi_sty) {
+	  props[0] = "props";
+	  props[1] = abi_sty;
+	  props[2] = 0;
+	} else {
+	  props[0] = 0;
+	}
+	  
 	_pushInlineFmt(props);
 	getDocument()->appendFmt(&m_vecInlineFmt);
       }
@@ -1460,6 +1465,9 @@ private:
     const XML_Char * height = UT_getAttribute ("svg:height", atts);
     const XML_Char * href   = UT_getAttribute ("xlink:href", atts);
 
+    if (width == NULL || height == NULL || href == NULL)
+        return; //don't crash on invalid images
+
     m_imgCnt++;
 
     UT_ByteBuf img_buf;
@@ -1679,15 +1687,15 @@ private:
 	if (m_vecInlineFmt.addItem(p)!=0)
 	  return false;
       }
-    if (!m_stackFmtStartIndex.push((void*)start))
+    if (!m_stackFmtStartIndex.push(start))
       return false;
     return true;
   }
   
   void _popInlineFmt(void)
   {
-    UT_uint32 start;
-    if (!m_stackFmtStartIndex.pop((void **)&start))
+    UT_sint32 start;
+    if (!m_stackFmtStartIndex.pop(&start))
       return;
     UT_uint32 k;
     UT_uint32 end = m_vecInlineFmt.getItemCount();
