@@ -97,7 +97,7 @@ int IE_Exp_DocBook :: unindent (void)
 	if (--s_align < 0)
 	{
 		s_align = 0;
-		printf ("trying to unindent at min indent.\n");
+		UT_DEBUGMSG (("trying to unindent at min indent.\n"));
 	}
 	return s_align;
 }
@@ -935,8 +935,8 @@ bool s_DocBook_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 					return false;
 
 			default:
-				UT_ASSERT(0);
-				return false;
+				UT_ASSERT(UT_TODO);
+				return true;
 			}
 			return false;
 		}
@@ -954,18 +954,20 @@ void s_DocBook_Listener::_openTable(PT_AttrPropIndex api)
 {
   UT_sint32 nCols = mTableHelper.getNumCols();
 
-  m_pie->write("\n<table frame=\"all\">\n");
+  m_pie->iwrite("<table frame=\"all\">\n");
+  m_pie->indent();
 
-  UT_String tgroup(UT_String_sprintf("<colgroup cols='%d' align='left' colsep='1' rowsep='1'>\n", nCols));
-  m_pie->write(tgroup.c_str(), tgroup.size());
+  UT_UTF8String tgroup(UT_UTF8String_sprintf("<tgroup cols='%d' align='left' colsep='1' rowsep='1'>\n", nCols));
+  m_pie->iwrite(tgroup.utf8_str());
 
   for (int i = 0; i < nCols; i++)
     {
-      UT_String colspec (UT_String_sprintf("<colspec colname='c%d'/>\n", i+1));
-      m_pie->write(colspec.c_str(), colspec.size());
+      UT_UTF8String colspec (UT_UTF8String_sprintf("<colspec colname='c%d'/>\n", i+1));
+      m_pie->iwrite(colspec.utf8_str());
     }
 
-  m_pie->write("<tbody>\n");
+  m_pie->iwrite("<tbody>\n");
+  m_pie->indent();
 }
 
 void s_DocBook_Listener::_openCell(PT_AttrPropIndex api)
@@ -978,7 +980,8 @@ void s_DocBook_Listener::_openCell(PT_AttrPropIndex api)
   if (mTableHelper.getLeft() == 0)
     {
       // beginning of a new row
-      m_pie->write("<row>\n");
+      m_pie->iwrite("<row>\n");
+      m_pie->indent();
     }
 
   UT_String entry ("<entry");
@@ -993,22 +996,30 @@ void s_DocBook_Listener::_openCell(PT_AttrPropIndex api)
 
   entry += ">\n";
   
-  m_pie->write(entry.c_str());	  
+  m_pie->iwrite(entry.c_str());	  
+  m_pie->indent();
 }
 
 void s_DocBook_Listener::_closeTable()
 {
-  m_pie->write("</tbody>\n</tgroup>\n</table>\n");
+  m_pie->unindent();
+  m_pie->iwrite("</tbody>\n");
+  m_pie->unindent();
+  m_pie->iwrite("</tgroup>\n");
+  m_pie->unindent();
+  m_pie->iwrite("</table>\n");
 }
 
 void s_DocBook_Listener::_closeCell()
 {
-  m_pie->write("</entry>\n");
+  m_pie->unindent();
+  m_pie->iwrite("</entry>\n");
 
   if ( mTableHelper.getNumCols () == mTableHelper.getRight () )
     {
       // logical end of a row
-      m_pie->write("</row>\n");
+      m_pie->unindent();
+      m_pie->iwrite("</row>\n");
     } 
 }
 
@@ -1196,9 +1207,9 @@ void s_DocBook_Listener::_handleDataItems(void)
 			/* int result = */
 			m_pDocument->getApp()->makeDirectory(fname.c_str(), 0750);
 			
-			if (!UT_strcmp(szMimeType, "image/svg-xml"))
+			if (!UT_strcmp(szMimeType, "image/svg+xml"))
 				UT_String_sprintf(fname, "%s/%s_%d.svg", fname.c_str(), szName, loc);
-			if (!UT_strcmp(szMimeType, "text/mathml"))
+			if (!UT_strcmp(szMimeType, "application/mathml+xml"))
 				UT_String_sprintf(fname, "%s/%s_%d.mathml", fname.c_str(), szName, loc);
 			else // PNG Image
 			{  
