@@ -134,8 +134,7 @@ wvGetBitmap (BitmapBlip * abm, MSOFBH * amsofbh, wvStream * fd)
 {
     U32 i, count;
     char extra = 0;
-    FILE *tmp;
-    wvStream * stm = 0;
+    wvStream * stm = NULL;
     wvTrace (("starting bitmap at %x\n", wvStream_tell (fd)));
     for (i = 0; i < 16; i++)
 	abm->m_rgbUid[i] = read_8ubit (fd);
@@ -176,15 +175,18 @@ wvGetBitmap (BitmapBlip * abm, MSOFBH * amsofbh, wvStream * fd)
     abm->m_pvBits = NULL;
 
     count++;
-    tmp = tmpfile ();
+    stm = wvStream_TMP_create (amsofbh->cbLength);
+
+    if (!stm) {
+      abm->m_pvBits = NULL;
+      return 0;
+    }
 
     for (i = count; i < amsofbh->cbLength; i++)
-	fputc (read_8ubit (fd), tmp);
-    fflush (tmp);
-    rewind (tmp);
-
-    wvStream_FILE_create (&stm, tmp);
-
+	write_8ubit (stm, read_8ubit (fd));
+    
+    wvStream_rewind (stm);
+    
     abm->m_pvBits = stm;
 
     count += i;
@@ -211,9 +213,8 @@ wvGetMetafile (MetaFileBlip * amf, MSOFBH * amsofbh, wvStream * fd)
 {
     char extra = 0;
     U32 i, count;
-    FILE *tmp;
     wvStream * stm = 0;
-    U8 decompressf = 0;
+    char *buf, *p;
 
     for (i = 0; i < 16; i++)
 	amf->m_rgbUid[i] = read_8ubit (fd);
@@ -270,40 +271,14 @@ wvGetMetafile (MetaFileBlip * amf, MSOFBH * amsofbh, wvStream * fd)
     amf->m_pvBits = NULL;
     count += 34;
 
-
-    if (amf->m_fCompression == msocompressionDeflate)
-	decompressf = setdecom ();
-
-    tmp = tmpfile ();
+    buf = malloc(amsofbh->cbLength);
+    p = buf;
 
     for (i = count; i < amsofbh->cbLength; i++)
-	fputc (read_8ubit (fd), tmp);
+	*p++ = read_8ubit (fd);
     count += i;
 
-    if (decompressf)
-      {
-	  /*
-	     FILE *final = fopen("/tmp/test.wmf","w+b");
-	   */
-	  FILE *final = tmpfile ();
-	  rewind (tmp);
-	  decompress (tmp, final, amf->m_cbSave, amf->m_cb);
-	  fclose (tmp);
-	  tmp = final;
-	  rewind (tmp);
-      }
-    
-   { 
-      long size;
-      char *buf;
-      fseek(tmp,0,SEEK_END);
-      size = ftell(tmp);
-      buf  = malloc(size);
-      rewind (tmp);
-      fread(buf,size,1,tmp);
-      fclose(tmp);
-      wvStream_memory_create (&stm, buf, size);
-    }
+    wvStream_memory_create (&stm, buf, amsofbh->cbLength);
 
     amf->m_pvBits = stm; 
 
