@@ -1334,7 +1334,7 @@ mySpecCharProc (wvParseStruct * ps, U16 eachchar, CHP * achp)
 			achp->fcPic_fcObj_lTagObj, achp->fObj, achp->fOle2));
 
 	      if (achp->fOle2)
-		  exit (139);
+		return (0);
 	      if(!no_graphics) 
 	      {
 	      wvStream_goto (ps->data, achp->fcPic_fcObj_lTagObj);
